## produces abundance evolution plot
## 

## uses:     isoAbund.out

## make multi-panel graph;
## set margins in order south, west, north, east
## oma is "outer margin" of entire figure
## mar is the margin of individual panels, which sets margin sizes in
##    order bottom, left, top, right
## mfcol=c(nrows, ncols) fills in the matrix by columns 
## tck sets tick mark lengths; negative value makes them point
##    outward
## las=1 shows tick mark labels in horizontal orientation
###   first value represents label locations [xlab, ylab], the second
###   the tick mark labels, the third the tick marks; default is c(3,1,0)

# for adding minor tick marks:
#library(Hmisc)

# read data from file
mydata <- read.table("isoAbund.out", header=FALSE, skip=1, na.strings = "")
print(mydata)
# write output to pdf file
pdf(file="isoAbund.pdf",width=6,height=5,onefile=F)

# define plot
par(mfcol=c(1,1), mar=c(1.5,6.5,1.0,3.0), oma=c(3.0,0.2,0.2,0.2), tck=0.05, 
    las=1, mgp=c(2.5,0.2,0))


## cex controls symbol size
## cex.yy controls label sizes
## pch is the symbol id
## xlim describes plot limits
## main adds a title
## mgp sets axis label locations relative to edge of inner plot window

# determine plotranges
xRang = max(mydata[, 1])-min(mydata[, 1])
yRang = max(mydata[, -1])-min(mydata[, -1])
limMult = 0.8
xLim= c( min(mydata[, 1])*limMult , max(mydata[, 1])/limMult )
yLim= c( min(mydata[, -1])*limMult , max(mydata[, -1])/limMult )

matplot(mydata[, 1], mydata[, -1], type="l", lt=1, log="xy", yaxt="n", xaxt="n",
        ylim=yLim, xlim=xLim, xlab=NA, ylab="Mass fraction", cex.lab=1.5, tck=0.03)


#text(mydatx$V2, mydatx$V3, label=mydatx$V1, col='blue', cex=0.4)

mtext(side = 1, "Time (s)", line = 2.0, cex=1.5)
#mtext(side = 2, "Mass fraction", line = 2.0, cex=1.5, srt=180)

axis(side=3, labels=FALSE, tck=0.03)
axis(side=4, labels=FALSE, tck=0.03)
#minor.tick(nx=10, ny=0, tick.ratio=0.5)


######### from web: to change "1 e xx" tick mark labels to "a x 10^y"
 axTexpr <- function(side, at = axTicks(side, axp=axp, usr=usr, log=log),
                    axp = NULL, usr = NULL, log = NULL)
 {
    ## Purpose: Do "a 10^k" labeling instead of "a e<k>"
    ##        this auxiliary should return 'at' and 'label' (expression)
    ## ----------------------------------------------------------------------
    ## Arguments: as for axTicks()
    ## ----------------------------------------------------------------------
    ## Author: Martin Maechler, Date:  7 May 2004, 18:01
    eT <- floor(log10(abs(at)))# at == 0 case is dealt with below
    mT <- at / 10^eT
    ss <- lapply(seq(along = at),
                 function(i) if(at[i] == 0) quote(0) else
                 substitute(10^E, list(A=mT[i], E=eT[i])))
    do.call("expression", ss)
 }
aY <- axTicks(2); axis(2, at=aY, label= axTexpr(2, aY), las=2, tck=0.03)
aX <- axTicks(1); axis(1, at=aX, label= axTexpr(1, aX), las=1)
########

## return output to the terminal
dev.off( )


